import QtQuick 2.6
import Sailfish.Silica 1.0
import QtSensors 5.2

Page {
    SilicaListView {
        id: sensorsListView
        anchors.fill: parent
        header: PageHeader { title: qsTr("Sensors") }
        model:  ListModel { }
        section {
            delegate: SectionHeader { text: section }
            property: "type"
        }
        delegate: ListItem {
            onClicked: pageStack.push(Qt.resolvedUrl('./%1Page.qml'.arg(model.type)),
                                      { sensorIdentifier: model.sensorIdentifier });
            Label {
                text: model.sensorIdentifier
                font.bold: model.isDefault
                anchors {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    right: parent.right
                    margins: Theme.horizontalPageMargin
                }
            }
        }
        Component.onCompleted: {
            QmlSensors.sensorTypes().forEach(function (sensorType) {
                console.log(sensorType);
                var defaultSensor = QmlSensors.defaultSensorForType(sensorType);
                QmlSensors.sensorsForType(sensorType).forEach(function (sensor) {
                    model.append({
                        sensorIdentifier: sensor,
                        type: sensorType,
                        isDefault: sensor === defaultSensor
                    })
                });
            });
        }

        ViewPlaceholder {
            text: qsTr("No sensors")
            enabled: sensorsListView.count === 0
        }
    }
}
